@@ -1,11 +1,11 @@
-# Copyright (C) 2017-2019  The Software Heritage developers
+# Copyright (C) 2017-2020  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
 from rest_framework.parsers import JSONParser
 
-from swh.model.identifiers import persistent_identifier, REVISION, DIRECTORY
+from swh.model.identifiers import DIRECTORY, persistent_identifier, REVISION, SNAPSHOT
 
 from . import SWHPrivateAPIView
 from ..common import SWHPutDepositAPI
@@ -14,6 +14,9 @@ from ...models import Deposit, DEPOSIT_STATUS_DETAIL
 from ...models import DEPOSIT_STATUS_LOAD_SUCCESS
 
 
+MANDATORY_KEYS = ["origin_url", "revision_id", "directory_id", "snapshot_id"]
+
+
 class SWHUpdateStatusDeposit(SWHPrivateAPIView, SWHPutDepositAPI):
     """Deposit request class to update the deposit's status.
 
@@ -29,6 +32,7 @@ class SWHUpdateStatusDeposit(SWHPrivateAPIView, SWHPutDepositAPI):
         New checks:
         - Ensure the status is provided
         - Ensure it exists
+        - no missing information on load success update
 
         """
         data = request.data
@@ -44,38 +48,57 @@ class SWHUpdateStatusDeposit(SWHPrivateAPIView, SWHPutDepositAPI):
             return make_error_dict(BAD_REQUEST, msg)
 
         if status == DEPOSIT_STATUS_LOAD_SUCCESS:
-            swh_id = data.get("revision_id")
-            if not swh_id:
-                msg = "Updating status to %s requires a revision_id key" % (status,)
+            missing_keys = []
+            for key in MANDATORY_KEYS:
+                value = data.get(key)
+                if value is None:
+                    missing_keys.append(key)
+
+            if missing_keys:
+                msg = (
+                    f"Updating deposit status to {status}"
+                    f" requires information {','.join(missing_keys)}"
+                )
                 return make_error_dict(BAD_REQUEST, msg)
 
         return {}
 
     def process_put(self, request, headers, collection_name, deposit_id):
-        """Update the deposit's status
+        """Update the deposit with status and SWHIDs
 
         Returns:
             204 No content
+            400 Bad request if checks fail
 
         """
+        data = request.data
+
         deposit = Deposit.objects.get(pk=deposit_id)
-        deposit.status = request.data["status"]  # checks already done before
 
-        origin_url = request.data.get("origin_url")
+        status = data["status"]
+        deposit.status = status
+        if status == DEPOSIT_STATUS_LOAD_SUCCESS:
+            origin_url = data["origin_url"]
+            directory_id = data["directory_id"]
+            revision_id = data["revision_id"]
+            dir_id = persistent_identifier(DIRECTORY, directory_id)
+            snp_id = persistent_identifier(SNAPSHOT, data["snapshot_id"])
+            rev_id = persistent_identifier(REVISION, revision_id)
 
-        dir_id = request.data.get("directory_id")
-        if dir_id:
-            deposit.swh_id = persistent_identifier(DIRECTORY, dir_id)
+            deposit.swh_id = dir_id
+            # new id with contextual information
             deposit.swh_id_context = persistent_identifier(
-                DIRECTORY, dir_id, metadata={"origin": origin_url}
-            )
-
-        rev_id = request.data.get("revision_id")
-        if rev_id:
-            deposit.swh_anchor_id = persistent_identifier(REVISION, rev_id)
-            deposit.swh_anchor_id_context = persistent_identifier(
-                REVISION, rev_id, metadata={"origin": origin_url}
+                DIRECTORY,
+                directory_id,
+                metadata={
+                    "origin": origin_url,
+                    "visit": snp_id,
+                    "anchor": rev_id,
+                    "path": "/",
+                },
             )
+        else:  # rejected
+            deposit.status = status
 
         deposit.save()
 
