@@ -1,4 +1,4 @@
-# Copyright (C) 2019  The Software Heritage developers
+# Copyright (C) 2019-2020  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -21,6 +21,7 @@ from typing import Mapping
 
 from swh.scheduler import get_scheduler
 from swh.scheduler.tests.conftest import *  # noqa
+from swh.model.identifiers import DIRECTORY, persistent_identifier, REVISION, SNAPSHOT
 from swh.deposit.config import setup_django_for
 from swh.deposit.parsers import parse_xml
 from swh.deposit.config import SWHDefaultConfig
@@ -403,11 +404,21 @@ def complete_deposit(sample_archive, deposit_collection, authenticated_client):
         external_id="external-id-complete",
         deposit_status=DEPOSIT_STATUS_LOAD_SUCCESS,
     )
-    _swh_id_context = "https://hal.archives-ouvertes.fr/hal-01727745"
-    deposit.swh_id = "swh:1:dir:42a13fc721c8716ff695d0d62fc851d641f3a12b"
-    deposit.swh_id_context = "%s;%s" % (deposit.swh_id, _swh_id_context)
-    deposit.swh_anchor_id = "swh:rev:1:548b3c0a2bb43e1fca191e24b5803ff6b3bc7c10"
-    deposit.swh_anchor_id_context = "%s;%s" % (deposit.swh_anchor_id, _swh_id_context)
+    origin = "https://hal.archives-ouvertes.fr/hal-01727745"
+    directory_id = "42a13fc721c8716ff695d0d62fc851d641f3a12b"
+    revision_id = "548b3c0a2bb43e1fca191e24b5803ff6b3bc7c10"
+    snapshot_id = "e5e82d064a9c3df7464223042e0c55d72ccff7f0"
+    deposit.swh_id = persistent_identifier(DIRECTORY, directory_id)
+    deposit.swh_id_context = persistent_identifier(
+        DIRECTORY,
+        directory_id,
+        metadata={
+            "origin": origin,
+            "visit": persistent_identifier(SNAPSHOT, snapshot_id),
+            "anchor": persistent_identifier(REVISION, revision_id),
+            "path": "/",
+        },
+    )
     deposit.save()
     return deposit
 
